# @summary A modern df command
#
# @example
#   include modern_shell_tools::install::lfs
#
# @param arch
# @param build
# @param version
# @param archive_name
# @param install_path
# @param bin_path
# @param create_path
#
class modern_shell_tools::install::lfs (
  String[1] $arch                    = $facts['os']['architecture'],
  String[1] $build                   = 'linux',
  String[1] $version                 = '2.5.0',
  String[1] $archive_name            = "lfs_${version}.zip",
  Stdlib::Absolutepath $install_path = "/opt/mst/lfs-${version}",
  Stdlib::Absolutepath $bin_path     = '/usr/local/sbin',
  Stdlib::Absolutepath $create_path  = "${install_path}/build",
) {
  include modern_shell_tools::install

  file { $install_path:
    ensure => directory,
  }

  -> archive { $archive_name:
    path         => "/tmp/${archive_name}",
    source       => "https://github.com/Canop/lfs/releases/download/v${version}/${archive_name}",
    extract      => true,
    extract_path => $install_path,
    creates      => $create_path,
    cleanup      => false,
  }

  -> file { "${bin_path}/lfs":
    ensure => link,
    target => "${create_path}/${arch}-${build}/lfs",
  }
}
